#[non_exhaustive]pub struct CreateEventDataStoreOutput {Show 13 fields
pub event_data_store_arn: Option<String>,
pub name: Option<String>,
pub status: Option<EventDataStoreStatus>,
pub advanced_event_selectors: Option<Vec<AdvancedEventSelector>>,
pub multi_region_enabled: Option<bool>,
pub organization_enabled: Option<bool>,
pub retention_period: Option<i32>,
pub termination_protection_enabled: Option<bool>,
pub tags_list: Option<Vec<Tag>>,
pub created_timestamp: Option<DateTime>,
pub updated_timestamp: Option<DateTime>,
pub kms_key_id: Option<String>,
pub billing_mode: Option<BillingMode>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.event_data_store_arn: Option<String>The ARN of the event data store.
name: Option<String>The name of the event data store.
status: Option<EventDataStoreStatus>The status of event data store creation.
advanced_event_selectors: Option<Vec<AdvancedEventSelector>>The advanced event selectors that were used to select the events for the data store.
multi_region_enabled: Option<bool>Indicates whether the event data store collects events from all Regions, or only from the Region in which it was created.
organization_enabled: Option<bool>Indicates whether an event data store is collecting logged events for an organization in Organizations.
retention_period: Option<i32>The retention period of an event data store, in days.
termination_protection_enabled: Option<bool>Indicates whether termination protection is enabled for the event data store.
A list of tags.
created_timestamp: Option<DateTime>The timestamp that shows when the event data store was created.
updated_timestamp: Option<DateTime>The timestamp that shows when an event data store was updated, if applicable. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.
kms_key_id: Option<String>Specifies the KMS key ID that encrypts the events delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the following format.
arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012
billing_mode: Option<BillingMode>The billing mode for the event data store.
Implementations
sourceimpl CreateEventDataStoreOutput
impl CreateEventDataStoreOutput
sourcepub fn event_data_store_arn(&self) -> Option<&str>
pub fn event_data_store_arn(&self) -> Option<&str>
The ARN of the event data store.
sourcepub fn status(&self) -> Option<&EventDataStoreStatus>
pub fn status(&self) -> Option<&EventDataStoreStatus>
The status of event data store creation.
sourcepub fn advanced_event_selectors(&self) -> &[AdvancedEventSelector]
pub fn advanced_event_selectors(&self) -> &[AdvancedEventSelector]
The advanced event selectors that were used to select the events for the data store.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .advanced_event_selectors.is_none().
sourcepub fn multi_region_enabled(&self) -> Option<bool>
pub fn multi_region_enabled(&self) -> Option<bool>
Indicates whether the event data store collects events from all Regions, or only from the Region in which it was created.
sourcepub fn organization_enabled(&self) -> Option<bool>
pub fn organization_enabled(&self) -> Option<bool>
Indicates whether an event data store is collecting logged events for an organization in Organizations.
sourcepub fn retention_period(&self) -> Option<i32>
pub fn retention_period(&self) -> Option<i32>
The retention period of an event data store, in days.
sourcepub fn termination_protection_enabled(&self) -> Option<bool>
pub fn termination_protection_enabled(&self) -> Option<bool>
Indicates whether termination protection is enabled for the event data store.
A list of tags.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags_list.is_none().
sourcepub fn created_timestamp(&self) -> Option<&DateTime>
pub fn created_timestamp(&self) -> Option<&DateTime>
The timestamp that shows when the event data store was created.
sourcepub fn updated_timestamp(&self) -> Option<&DateTime>
pub fn updated_timestamp(&self) -> Option<&DateTime>
The timestamp that shows when an event data store was updated, if applicable. UpdatedTimestamp is always either the same or newer than the time shown in CreatedTimestamp.
sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
Specifies the KMS key ID that encrypts the events delivered by CloudTrail. The value is a fully specified ARN to a KMS key in the following format.
arn:aws:kms:us-east-2:123456789012:key/12345678-1234-1234-1234-123456789012
sourcepub fn billing_mode(&self) -> Option<&BillingMode>
pub fn billing_mode(&self) -> Option<&BillingMode>
The billing mode for the event data store.
sourceimpl CreateEventDataStoreOutput
impl CreateEventDataStoreOutput
sourcepub fn builder() -> CreateEventDataStoreOutputBuilder
pub fn builder() -> CreateEventDataStoreOutputBuilder
Creates a new builder-style object to manufacture CreateEventDataStoreOutput.