pub struct StartQueryFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to StartQuery.
Starts a CloudTrail Lake query. Use the QueryStatement parameter to provide your SQL query, enclosed in single quotation marks. Use the optional DeliveryS3Uri parameter to deliver the query results to an S3 bucket.
StartQuery requires you specify either the QueryStatement parameter, or a QueryAlias and any QueryParameters. In the current release, the QueryAlias and QueryParameters parameters are used only for the queries that populate the CloudTrail Lake dashboards.
Implementations
sourceimpl StartQueryFluentBuilder
impl StartQueryFluentBuilder
sourcepub fn as_input(&self) -> &StartQueryInputBuilder
pub fn as_input(&self) -> &StartQueryInputBuilder
Access the StartQuery as a reference.
sourcepub async fn send(
self
) -> Result<StartQueryOutput, SdkError<StartQueryError, HttpResponse>>
pub async fn send( self ) -> Result<StartQueryOutput, SdkError<StartQueryError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn customize(
self
) -> CustomizableOperation<StartQueryOutput, StartQueryError, Self>
pub fn customize( self ) -> CustomizableOperation<StartQueryOutput, StartQueryError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
sourcepub fn query_statement(self, input: impl Into<String>) -> Self
pub fn query_statement(self, input: impl Into<String>) -> Self
The SQL code of your query.
sourcepub fn set_query_statement(self, input: Option<String>) -> Self
pub fn set_query_statement(self, input: Option<String>) -> Self
The SQL code of your query.
sourcepub fn get_query_statement(&self) -> &Option<String>
pub fn get_query_statement(&self) -> &Option<String>
The SQL code of your query.
sourcepub fn delivery_s3_uri(self, input: impl Into<String>) -> Self
pub fn delivery_s3_uri(self, input: impl Into<String>) -> Self
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn set_delivery_s3_uri(self, input: Option<String>) -> Self
pub fn set_delivery_s3_uri(self, input: Option<String>) -> Self
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn get_delivery_s3_uri(&self) -> &Option<String>
pub fn get_delivery_s3_uri(&self) -> &Option<String>
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn query_alias(self, input: impl Into<String>) -> Self
pub fn query_alias(self, input: impl Into<String>) -> Self
The alias that identifies a query template.
sourcepub fn set_query_alias(self, input: Option<String>) -> Self
pub fn set_query_alias(self, input: Option<String>) -> Self
The alias that identifies a query template.
sourcepub fn get_query_alias(&self) -> &Option<String>
pub fn get_query_alias(&self) -> &Option<String>
The alias that identifies a query template.
sourcepub fn query_parameters(self, input: impl Into<String>) -> Self
pub fn query_parameters(self, input: impl Into<String>) -> Self
Appends an item to QueryParameters.
To override the contents of this collection use set_query_parameters.
The query parameters for the specified QueryAlias.
sourcepub fn set_query_parameters(self, input: Option<Vec<String>>) -> Self
pub fn set_query_parameters(self, input: Option<Vec<String>>) -> Self
The query parameters for the specified QueryAlias.
sourcepub fn get_query_parameters(&self) -> &Option<Vec<String>>
pub fn get_query_parameters(&self) -> &Option<Vec<String>>
The query parameters for the specified QueryAlias.