#[non_exhaustive]pub struct StartQueryInputBuilder { /* private fields */ }Expand description
A builder for StartQueryInput.
Implementations
sourceimpl StartQueryInputBuilder
impl StartQueryInputBuilder
sourcepub fn query_statement(self, input: impl Into<String>) -> Self
pub fn query_statement(self, input: impl Into<String>) -> Self
The SQL code of your query.
sourcepub fn set_query_statement(self, input: Option<String>) -> Self
pub fn set_query_statement(self, input: Option<String>) -> Self
The SQL code of your query.
sourcepub fn get_query_statement(&self) -> &Option<String>
pub fn get_query_statement(&self) -> &Option<String>
The SQL code of your query.
sourcepub fn delivery_s3_uri(self, input: impl Into<String>) -> Self
pub fn delivery_s3_uri(self, input: impl Into<String>) -> Self
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn set_delivery_s3_uri(self, input: Option<String>) -> Self
pub fn set_delivery_s3_uri(self, input: Option<String>) -> Self
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn get_delivery_s3_uri(&self) -> &Option<String>
pub fn get_delivery_s3_uri(&self) -> &Option<String>
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn query_alias(self, input: impl Into<String>) -> Self
pub fn query_alias(self, input: impl Into<String>) -> Self
The alias that identifies a query template.
sourcepub fn set_query_alias(self, input: Option<String>) -> Self
pub fn set_query_alias(self, input: Option<String>) -> Self
The alias that identifies a query template.
sourcepub fn get_query_alias(&self) -> &Option<String>
pub fn get_query_alias(&self) -> &Option<String>
The alias that identifies a query template.
sourcepub fn query_parameters(self, input: impl Into<String>) -> Self
pub fn query_parameters(self, input: impl Into<String>) -> Self
Appends an item to query_parameters.
To override the contents of this collection use set_query_parameters.
The query parameters for the specified QueryAlias.
sourcepub fn set_query_parameters(self, input: Option<Vec<String>>) -> Self
pub fn set_query_parameters(self, input: Option<Vec<String>>) -> Self
The query parameters for the specified QueryAlias.
sourcepub fn get_query_parameters(&self) -> &Option<Vec<String>>
pub fn get_query_parameters(&self) -> &Option<Vec<String>>
The query parameters for the specified QueryAlias.
sourcepub fn build(self) -> Result<StartQueryInput, BuildError>
pub fn build(self) -> Result<StartQueryInput, BuildError>
Consumes the builder and constructs a StartQueryInput.
sourceimpl StartQueryInputBuilder
impl StartQueryInputBuilder
sourcepub async fn send_with(
self,
client: &Client
) -> Result<StartQueryOutput, SdkError<StartQueryError, HttpResponse>>
pub async fn send_with( self, client: &Client ) -> Result<StartQueryOutput, SdkError<StartQueryError, HttpResponse>>
Sends a request with this input using the given client.