Struct aws_sdk_cloudtrail::operation::start_query::StartQueryInput
source · #[non_exhaustive]pub struct StartQueryInput {
pub query_statement: Option<String>,
pub delivery_s3_uri: Option<String>,
pub query_alias: Option<String>,
pub query_parameters: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.query_statement: Option<String>The SQL code of your query.
delivery_s3_uri: Option<String>The URI for the S3 bucket where CloudTrail delivers the query results.
query_alias: Option<String>The alias that identifies a query template.
query_parameters: Option<Vec<String>>The query parameters for the specified QueryAlias.
Implementations
sourceimpl StartQueryInput
impl StartQueryInput
sourcepub fn query_statement(&self) -> Option<&str>
pub fn query_statement(&self) -> Option<&str>
The SQL code of your query.
sourcepub fn delivery_s3_uri(&self) -> Option<&str>
pub fn delivery_s3_uri(&self) -> Option<&str>
The URI for the S3 bucket where CloudTrail delivers the query results.
sourcepub fn query_alias(&self) -> Option<&str>
pub fn query_alias(&self) -> Option<&str>
The alias that identifies a query template.
sourcepub fn query_parameters(&self) -> &[String]
pub fn query_parameters(&self) -> &[String]
The query parameters for the specified QueryAlias.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .query_parameters.is_none().
sourceimpl StartQueryInput
impl StartQueryInput
sourcepub fn builder() -> StartQueryInputBuilder
pub fn builder() -> StartQueryInputBuilder
Creates a new builder-style object to manufacture StartQueryInput.