#[non_exhaustive]
pub struct AdvancedEventSelector { pub name: Option<String>, pub field_selectors: Vec<AdvancedFieldSelector>, }
Advanced event selectors let you create fine-grained selectors for CloudTrail management and data events. They help you control costs by logging only those events that are important to you. For more information about advanced event selectors, see Logging management events and Logging data events in the CloudTrail User Guide.

You cannot apply both event selectors and advanced event selectors to a trail.

Supported CloudTrail event record fields for management events

  • eventCategory (required)

  • eventSource

  • readOnly

Supported CloudTrail event record fields for data events

  • eventCategory (required)

  • resources.type (required)

  • readOnly

  • eventName

  • resources.ARN

For event data stores for CloudTrail Insights events, Config configuration items, Audit Manager evidence, or events outside of Amazon Web Services, the only supported field is eventCategory.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: Option<String>

An optional, descriptive name for an advanced event selector, such as "Log data events for only two S3 buckets".

field_selectors: Vec<AdvancedFieldSelector>

Contains all selector statements in an advanced event selector.

Implementations

source

impl AdvancedEventSelector

source

pub fn name(&self) -> Option<&str>

An optional, descriptive name for an advanced event selector, such as "Log data events for only two S3 buckets".

source

pub fn field_selectors(&self) -> &[AdvancedFieldSelector]

Contains all selector statements in an advanced event selector.

source

impl AdvancedEventSelector

source

pub fn builder() -> AdvancedEventSelectorBuilder

Creates a new builder-style object to manufacture AdvancedEventSelector.