Struct aws_sdk_cloudtrail::types::AdvancedEventSelector
source · #[non_exhaustive]pub struct AdvancedEventSelector {
pub name: Option<String>,
pub field_selectors: Vec<AdvancedFieldSelector>,
}Expand description
Advanced event selectors let you create fine-grained selectors for CloudTrail management and data events. They help you control costs by logging only those events that are important to you. For more information about advanced event selectors, see Logging management events and Logging data events in the CloudTrail User Guide.
You cannot apply both event selectors and advanced event selectors to a trail.
Supported CloudTrail event record fields for management events
-
eventCategory(required) -
eventSource -
readOnly
Supported CloudTrail event record fields for data events
-
eventCategory(required) -
resources.type(required) -
readOnly -
eventName -
resources.ARN
For event data stores for CloudTrail Insights events, Config configuration items, Audit Manager evidence, or events outside of Amazon Web Services, the only supported field is eventCategory.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>An optional, descriptive name for an advanced event selector, such as "Log data events for only two S3 buckets".
field_selectors: Vec<AdvancedFieldSelector>Contains all selector statements in an advanced event selector.
Implementations
sourceimpl AdvancedEventSelector
impl AdvancedEventSelector
sourcepub fn name(&self) -> Option<&str>
pub fn name(&self) -> Option<&str>
An optional, descriptive name for an advanced event selector, such as "Log data events for only two S3 buckets".
sourcepub fn field_selectors(&self) -> &[AdvancedFieldSelector]
pub fn field_selectors(&self) -> &[AdvancedFieldSelector]
Contains all selector statements in an advanced event selector.
sourceimpl AdvancedEventSelector
impl AdvancedEventSelector
sourcepub fn builder() -> AdvancedEventSelectorBuilder
pub fn builder() -> AdvancedEventSelectorBuilder
Creates a new builder-style object to manufacture AdvancedEventSelector.